@@ -1,5 +1,5 @@
 import pytest
-
+import copy
 from pytest_influxdb.data_manager import DataManager
 from pytest_influxdb.influxdb_components import Influxdb_Components
 from pytest_influxdb.suite_result_dto import SuiteResultDTO
@@ -30,9 +30,10 @@ def test_result(request, pytestconfig, get_influxdb, run, influxdb_project, vers
     if pytestconfig.getoption('--pytest-influxdb'):
         def send_test_data_to_db():
             # Generating test data
+            test_influxdb_values = copy.deepcopy(influxdb_values)
             data_manager.save_db_data_in_properties(request=request, db_host=db_host, db_port=db_port, db_user=db_user,
                                                     db_password=db_password, db_name=db_name,
-                                                    influxdb_values=influxdb_values, run=run, project=influxdb_project,
+                                                    influxdb_values=test_influxdb_values, run=run, project=influxdb_project,
                                                     version=version, merged=merged)
 
             test_result_dto.set_test_result_data(influxdb_project, version, run, data_manager.get_report(request), merged,
@@ -272,4 +273,4 @@ def are_tests_skipped(terminalreporter_values):
     all_tests = terminalreporter_values.get('')
     if 'skipped' in terminalreporter_values:
         are_all_tests_skipped = len(all_tests) == len(terminalreporter_values['skipped'])
-    return are_all_tests_skipped
\ No newline at end of file
+    return are_all_tests_skipped
